"use strict";
this.author    = "Zafrusteria";
this.copyright = "© 2024 Zafrusteria.";
this.license   = "Creative Commons: attribution, non-commercial,  CC BY-NC-SA 4.0 sharealike with clauses - see License.txt";
this.version   = "0.5";

this.name      = "ShrewsRights_ads_horz";
this.description = "ShrewsRights for Market Ads";

this.$antiShrew = false;
this.$proShrew  = false;
this.$wanted    = false;

this.$debug = false;

this.startUpComplete = function _ShrewsRights_horz_startUpComplete() {
    if (galaxyNumber != 1 || player.score < 512) return;

    let SR = worldScripts.ShrewsRights;
    if (this.$debug) log(this.name, "Startup horz SR missionStage: " + SR.$missionStage)

    this._addAntiShrewAds(SR.$missionStage);
    this._addProShrewAds(SR.$missionStage);
    this._addWantedPosters(SR.$missionNewsCount);

    let wsSt = worldScripts.station_ads;
    let wsSe = worldScripts.market_ads_service;
    // just adverts, always available
    if (this.$debug) log(this.name, "add horz ads");
    for (let i = 0; i < 16; i++) {
        if (wsSt) wsSt._setHorzAd("ShrewsRights_horz_" + (150 + i) + ".png");
        if (wsSe) wsSe._setHorzAd("ShrewsRights_horz_" + (150 + i) + ".png");
    }
}

this.missionScreenOpportunity = function _ShrewsRights_horz_missionScreenOpportunity() {
    if (galaxyNumber != 1 || player.score < 512) return;

    let SR = worldScripts.ShrewsRights;
    if (this.$debug) log(this.name, "missionScreenOpportunity testing horz ads " + SR.$missionStage)

    this._delAntiShrewAds(SR.$missionStage);
    this._addProShrewAds(SR.$missionNewsCount);
    this._addWantedPosters(SR.$missionNewsCount);
}

this._addAntiShrewAds = function _ShrewsRights_horz_addAntiShrewAds(stage) {
    if (! this.$antiShrew && stage > 0 && stage < 14) {
        if (this.$debug) log(this.name, "_addAntiShrewAds horz");
        this.$antiShrew = true;

        let wsSt = worldScripts.station_ads;
        let wsSe = worldScripts.market_ads_service;
        // Ads for eating Shrews, these stop when Shrews are welcomed as citizens
        // the outer loop so they will appear more often.
        for (let j = 0; j < 4; j++) {
            for (let i = 1; i < 11; i++) {
                if (wsSt) wsSt._setHorzAd("ShrewsRights_horz_" + i + ".png");
                if (wsSe) wsSe._setHorzAd("ShrewsRights_horz_" + i + ".png");
            }
        }
        // Take these new ads into use as we added them after setup.
        // ** Probably not the best way to do this. **
        wsSt._initHorzPool();
        wsSe._initHorzPool();
    }
}

this._delAntiShrewAds = function _ShrewsRights_horz_delAntiShrewAds(stage) {
    let regexKey =  new RegExp("ShrewsRights_horz_[1-4]?[0-9].png");
    function checkAntiShrew(key) { return ! regexKey.test(key);}

    if (this.$antiShrew && stage >= 14) {
        if (this.$debug) log(this.name, "_delAntiShrewAds horz");
        this.$antiShrew = false;

        let wsSt = worldScripts.station_ads;
        let wsSe = worldScripts.market_ads_service;
        if (wsSt && wsSt.$horzAdPool) {
            wsSt.$horzAdPool = wsSt.$horzAdPool.filter(checkAntiShrew);
            // remove these ads from the service
            wsSt._initHorzPool();

        }
        if (wsSe && wsSe.$horzAdPool) {
            wsSe.$horzAdPool = wsSe.$horzAdPool.filter(checkAntiShrew);
            // remove these ads from the service
            wsSe._initHorzPool();
        }
    }
}

this._addProShrewAds = function _ShrewsRights_horz_addProShrewAds(news) {
    if (! this.$proShrew && news >= 11) {
        if (this.$debug) log(this.name, "_addProShrewAds horz");
        this.$proShrew = true;

        let wsSt = worldScripts.station_ads;
        let wsSe = worldScripts.market_ads_service;
        for (let i = 0; i < 12; i++) {
            if (wsSt) wsSt._setHorzAd("ShrewsRights_horz_" + (50 + i) + ".png");
            if (wsSe) wsSe._setHorzAd("ShrewsRights_horz_" + (50 + i) + ".png");
        }
        // Take these new ads into use
        wsSt._initHorzPool();
        wsSe._initHorzPool();
    }
}

this._addWantedPosters = function _ShrewsRights_horz_addWantedPosters(news) {
    if (! this.$wanted && news >= 16) {
        if (this.$debug) log(this.name, "_addWantedPosters horz");
        this.$wanted = true;

        let wsSt = worldScripts.station_ads;
        let wsSe = worldScripts.market_ads_service;
        for (let i = 0; i < 4; i++) {
            if (wsSt) wsSt._setHorzAd("ShrewsRights_horz_" + (100 + i) + ".png");
            if (wsSe) wsSe._setHorzAd("ShrewsRights_horz_" + (100 + i) + ".png");
        }
        // Take these new ads into use
        wsSt._initHorzPool();
        wsSe._initHorzPool();
    }
}